package com.dotsource.intershop.sofort.pipelet;

import com.dotsource.intershop.sofort.payment.SofortConstants;
import com.dotsource.intershop.sofort.payment.SofortPaymentService;
import com.dotsource.intershop.sofort.payment.SofortPaymentStatus;
import com.intershop.beehive.bts.capi.payment.PaymentTransaction;
import com.intershop.beehive.core.capi.pipeline.Pipelet;
import com.intershop.beehive.core.capi.pipeline.PipeletExecutionException;
import com.intershop.beehive.core.capi.pipeline.PipelineDictionary;
import com.intershop.component.payment.capi.PaymentServiceProxy;

public class RequestSofortStatusResult extends Pipelet implements SofortConstants
{

    /**
     * Constant used to access the pipeline dictionary with key
     * 'PaymentTransaction'
     */
    public static final String DN_PAYMENT_TRANSACTION = "PaymentTransaction";

    /**
     * Constant used to access the pipeline dictionary with key 'ResultStatus'
     */
    public static final String DN_PAYMENT_STATUS = "SofortPaymentStatus";

    /**
     * Constant used to access the pipeline dictionary with key 'Type'
     */
    public static final String DN_TYPE = "RequestType";

    @Override
    public int execute(PipelineDictionary dict) throws PipeletExecutionException
    {
        // lookup 'Type' in pipeline dictionary
        String type = (String)dict.get(DN_TYPE);
        if (null == type)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'RequestType' not available in pipeline dictionary.");
        }

        // lookup 'PaymentTransaction' in pipeline dictionary
        PaymentTransaction paymentTransaction = (PaymentTransaction)dict.get(DN_PAYMENT_TRANSACTION);
        if (null == paymentTransaction)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'PaymentTransaction' not available in pipeline dictionary.");
        }
        SofortPaymentStatus sofoStatus = new SofortPaymentStatus(STATUS_RESULT_FAILED, "unknown", "unknown", "unknown", 0.0 , 0.0, type);
        
        PaymentServiceProxy proxy = (PaymentServiceProxy)paymentTransaction.getPaymentService();

        SofortPaymentService service = (SofortPaymentService)proxy.getDelegate();

        if (service != null)
        {
            sofoStatus = service.getStatusResult(paymentTransaction, type);
        }


        // put ResultStatus to dict
        dict.put(DN_PAYMENT_STATUS, sofoStatus);

        return PIPELET_NEXT;
    }
}
