package com.dotsource.intershop.sofort.pipelet;

import com.intershop.beehive.core.capi.pipeline.Pipelet;
import com.intershop.beehive.core.capi.pipeline.PipeletExecutionException;
import com.intershop.beehive.core.capi.pipeline.PipelineDictionary;

/**
 * This pipelet can be used to wait a defined time of milliseconds.
 */
public class WaitCustomTime extends Pipelet
{

    public static final String DN_CUSTOM_TIME = "CustomTime";
    
    @Override
    public int execute(PipelineDictionary dict) throws PipeletExecutionException
    {
        String customTimeString = (String)dict.get(DN_CUSTOM_TIME);
        int customTimeValue;
        if (null == customTimeString)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'CustomTime' not available in pipeline dictionary.");
        }
        try {
            customTimeValue = new Integer(customTimeString);
        } catch(NumberFormatException e) {
            throw new PipeletExecutionException("Input parameter 'CustomTime' cannot be converted to an integer.");
        }
        if (customTimeValue <= 0)
        {
            throw new PipeletExecutionException("Input parameter 'CustomTime' must be greater than 0.");
        }

        try
        {
            Thread.sleep(customTimeValue);
        }
        catch(InterruptedException ex)
        {
            /* ignored */
        }

        return PIPELET_NEXT;
    }

}
